<?php

namespace Drupal\paragraphs_role_visibility\Plugin\paragraphs\Behavior;

use Drupal\Core\Entity\Display\EntityViewDisplayInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\paragraphs\Entity\Paragraph;
use Drupal\paragraphs\ParagraphInterface;
use Drupal\paragraphs\ParagraphsBehaviorBase;
use Drupal\user\Entity\Role;

/**
 * Allows to set role access for paragraph item visibility.
 *
 * @ParagraphsBehavior(
 *   id = "paragraphs_role_visibility",
 *   label = @Translation("Paragraph visibility"),
 *   description = @Translation("Set access for viewing paragraph by roles."),
 *   weight = 0
 * )
 *
 * @package Drupal\paragraphs_role_visibility\Plugin\paragraphs\Behavior
 */
class ParagraphsRoleVisibility extends ParagraphsBehaviorBase {

  /**
   * {@inheritDoc}
   */
  public function buildBehaviorForm(ParagraphInterface $paragraph, array &$form, FormStateInterface $form_state) {
    $roles_options = [];
    $roles = Role::loadMultiple();

    if (is_array($roles)) {
      foreach ($roles as $role) {
        $roles_options[$role->id()] = $role->label();
      }
    }

    $form['paragraphs_role_visibility'] = [
      '#type' => 'checkboxes',
      '#options' => $roles_options,
      '#title' => $this->t('Paragraph visibility by roles'),
      '#description' => $this->t('Make paragraph visible for selected roles.'),
      '#default_value' => $paragraph->getBehaviorSetting($this->getPluginId(), 'paragraphs_role_visibility', array_keys($roles_options)),
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritDoc}
   */
  public function settingsSummary(Paragraph $paragraph) {
    $access_view = $paragraph->getBehaviorSetting($this->getPluginId(), 'paragraphs_role_visibility');
    $value = (!$access_view) ? $this->t('all roles') : implode(", ", array_keys($access_view));

    return [
      [
        'label' => $this->t('Paragraph visible for'),
        'value' => $value,
      ],
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function view(array &$build, Paragraph $paragraph, EntityViewDisplayInterface $display, $view_mode) {

  }

}
