<?php

namespace Drupal\Tests\paragraphs_role_visibility\Functional;

use Drupal\Tests\paragraphs\Functional\WidgetStable\ParagraphsTestBase;

/**
 * Tests Paragraphs Role Visibility behavior plugin.
 *
 * @group paragraphs
 */
class ParagraphsRoleVisibilityTest extends ParagraphsTestBase {

  /**
   * Modules to enable.
   *
   * @var string[]
   */
  protected static $modules = [
    'node',
    'paragraphs_role_visibility',
  ];

  /**
   * Tests the behavior visibility settings.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function testParagraphsRoleVisibility() {
    $this->addParagraphedContentType('paragraphed_test');
    $user = $this->drupalCreateUser();
    $admin = $this->drupalCreateUser([
      'create paragraphed_test content',
      'edit any paragraphed_test content',
      'edit behavior plugin settings',
      'administer paragraphs types',
    ]);
    $this->drupalLogin($admin);

    // Add a text Paragraph type.
    $paragraph_type = 'text_paragraph';
    $this->addParagraphsType($paragraph_type);
    $this->addFieldtoParagraphType($paragraph_type, 'field_text', 'text_long');

    // Enable the "Paragraph visibility" plugin to have a behavior form.
    $this->drupalGet('/admin/structure/paragraphs_type/' . $paragraph_type);
    $edit = [
      'behavior_plugins[paragraphs_role_visibility][enabled]' => TRUE,
    ];
    $this->submitForm($edit, 'Save');
    $this->assertSame(['paragraphs_role_visibility' => ['enabled' => TRUE]], $this->config("paragraphs.paragraphs_type.$paragraph_type")->get('behavior_plugins'));

    $this->drupalGet('node/add/paragraphed_test');

    // Create a node with paragraph and make it visible for authenticated users
    // but not for anonymous.
    $edit = [
      'title[0][value]' => 'Test Node',
      'field_paragraphs[0][subform][field_text][0][value]' => 'Paragraph text',
      'field_paragraphs[0][behavior_plugins][paragraphs_role_visibility][paragraphs_role_visibility][anonymous]' => FALSE,
      'field_paragraphs[0][behavior_plugins][paragraphs_role_visibility][paragraphs_role_visibility][authenticated]' => TRUE,
    ];
    $this->submitForm($edit, 'Save');
    $node = $this->getNodeByTitle('Test Node', TRUE);

    // Check that user is authenticated and can see the paragraph.
    $this->drupalLogin($user);
    $this->drupalGet('node/' . $node->id());
    $this->assertTrue($user->isAuthenticated());
    $text = $this->getSession()->getPage()->getText();
    $this->assertStringContainsString('Paragraph text', $text);

    // Logout and check that anonymous user can't see the paragraph.
    $this->drupalLogout();
    $this->drupalGet('node/' . $node->id());
    $text = $this->getSession()->getPage()->getText();
    $this->assertStringNotContainsString('Paragraph text', $text);

    // Edit node and make paragraph visible for anonymous users
    // but not for authenticated.
    $this->drupalLogin($admin);
    $this->drupalGet('node/' . $node->id() . '/edit');
    $edit = [
      'field_paragraphs[0][behavior_plugins][paragraphs_role_visibility][paragraphs_role_visibility][anonymous]' => TRUE,
      'field_paragraphs[0][behavior_plugins][paragraphs_role_visibility][paragraphs_role_visibility][authenticated]' => FALSE,
    ];
    $this->submitForm($edit, 'Save');

    // Check that user is authenticated and can't see the paragraph.
    $this->drupalLogin($user);
    $this->drupalGet('node/' . $node->id());
    $this->assertTrue($user->isAuthenticated());
    $text = $this->getSession()->getPage()->getText();
    $this->assertStringNotContainsString('Paragraph text', $text);

    // Logout and check that anonymous user can see the paragraph.
    $this->drupalLogout();
    $this->drupalGet('node/' . $node->id());
    $text = $this->getSession()->getPage()->getText();
    $this->assertStringContainsString('Paragraph text', $text);
  }

}
